@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 //  PyAOgmaNeo
-//  Copyright(c) 2020 Ogma Intelligent Systems Corp. All rights reserved.
+//  Copyright(c) 2020-2023 Ogma Intelligent Systems Corp. All rights reserved.
 //
 //  This copy of PyAOgmaNeo is licensed to you under the terms described
 //  in the PYAOGMANEO_LICENSE.md file included in this distribution.
@@ -8,13 +8,15 @@
 
 #include "PyHelpers.h"
 
+#include <assert.h>
+
 using namespace pyaon;
 
-void StreamReader::read(void* data, int len) {
+void FileReader::read(void* data, int len) {
     ins.read(static_cast<char*>(data), len);
 }
 
-void StreamWriter::write(const void* data, int len) {
+void FileWriter::write(const void* data, int len) {
     outs.write(static_cast<const char*>(data), len);
 }
 
@@ -26,10 +28,10 @@ void BufferReader::read(void* data, int len) {
 }
 
 void BufferWriter::write(const void* data, int len) {
-    int start = buffer.size();
-
-    buffer.resize(buffer.size() + len);
+    assert(buffer.size() >= start + len);
 
     for (int i = 0; i < len; i++)
         buffer[start + i] = static_cast<const unsigned char*>(data)[i];
+
+    start += len;
 }
