@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 //  PyAOgmaNeo
-//  Copyright(c) 2020 Ogma Intelligent Systems Corp. All rights reserved.
+//  Copyright(c) 2020-2023 Ogma Intelligent Systems Corp. All rights reserved.
 //
 //  This copy of PyAOgmaNeo is licensed to you under the terms described
 //  in the PYAOGMANEO_LICENSE.md file included in this distribution.
@@ -10,11 +10,16 @@
 
 #include <aogmaneo/Helpers.h>
 #include <tuple>
+#include <string>
 #include <vector>
 #include <fstream>
+#include <iostream>
+#include <exception>
 
 namespace pyaon {
-inline void setNumThreads(int numThreads) {
+inline void setNumThreads(
+    int numThreads
+) {
     aon::setNumThreads(numThreads);
 }
 
@@ -22,7 +27,17 @@ inline int getNumThreads() {
     return aon::getNumThreads();
 }
 
-class StreamReader : public aon::StreamReader {
+inline void setGlobalState(
+    unsigned int state
+) {
+    aon::globalState = state;
+}
+
+inline unsigned int getGlobalState() {
+    return aon::globalState;
+}
+
+class FileReader : public aon::StreamReader {
 public:
     std::ifstream ins;
 
@@ -32,7 +47,7 @@ public:
     ) override;
 };
 
-class StreamWriter : public aon::StreamWriter {
+class FileWriter : public aon::StreamWriter {
 public:
     std::ofstream outs;
 
@@ -61,8 +76,18 @@ public:
 
 class BufferWriter : public aon::StreamWriter {
 public:
+    int start;
     std::vector<unsigned char> buffer;
 
+    BufferWriter(
+        int bufferSize
+    )
+    :
+    start(0)
+    {
+        buffer.resize(bufferSize);
+    }
+
     void write(
         const void* data,
         int len
